@@ -6,9 +6,10 @@ __docformat__ = 'reStructuredText'
 
 
 import os, sys
+import logging
 import os.path
 
-import logging
+
 import json
 from pprint import pprint
 import matplotlib
@@ -24,6 +25,8 @@ from pax2graphml import utils
 from pax2graphml import properties
 from pax2graphml import graph_explore
 
+logger = logging.getLogger(__name__)
+logger.addHandler(logging.NullHandler())
  
 def biopax_to_reaction_graph(biopax_file,graphml_file,blackList=None):
 
@@ -44,7 +47,7 @@ def biopax_to_reaction_graph(biopax_file,graphml_file,blackList=None):
        blackListOpt=""
 
     cmd="%s %s -cp %s %s -i '%s' -o '%s' -t '%s' %s" %(utils.__jvm(),utils.__jvmopt(),utils.__jarpath(),cls,biopax_file,graphml_file,utils.__template(), blackListOpt)
-
+    logger.info("command : %s" %(cmd))
     return utils.__runCmd(cmd)
 
 
@@ -67,6 +70,7 @@ def biopax_merge(biopax_list,output_file="output.owl"):
 
 
     cmd="%s %s -cp %s %s -i '%s' -o '%s'" %(utils.__jvm(),utils.__jvmopt(),utils.__jarpath(),cls,biopax_filestr,output_file)
+    logger.info("command : %s" %(cmd))
     return utils.__runCmd(cmd)
 
  
@@ -84,6 +88,7 @@ def biopax_filter(biopax_file,datasources,output_file="output.owl"):
     cls="dyliss.biopax.app.BioPaxFilter"
     filterd=":".join(datasources)
     cmd="%s %s -cp %s %s  %s %s %s" %(utils.__jvm(),utils.__jvmopt(),utils.__jarpath(),cls,biopax_file,filterd,output_file)
+    logger.info("command : %s" %(cmd))
     return utils.__runCmd(cmd)
 
 
@@ -102,6 +107,7 @@ def name_alias(biopax_file,output_file="entities_aliases.json",opt="--uri-ids"):
     """   
     cls="dyliss.biopax.app.P2GAliasProcessor"  
     cmd="%s %s -cp %s %s NAME_ALIAS '%s' '%s' %s" %(utils.__jvm(),utils.__jvmopt(),utils.__jarpath(),cls,biopax_file,output_file,opt)
+    logger.info("command : %s" %(cmd))
     return utils.__runCmd(cmd)
 
 
@@ -219,7 +225,7 @@ def __linkEdges(g, displayProgress=False):
     for r in reaction:
 
         if (displayProgress):
-            print(str(count)+" / "+str(len(reaction))+" edges")
+            logger.info(str(count)+" / "+str(len(reaction))+" edges")
             count+=1
 
         source=[]
@@ -241,7 +247,7 @@ def __linkEdges(g, displayProgress=False):
 
 
                  try:
-                        logging.info("LINK PRODUCT")
+                        logger.info("LINK PRODUCT")
                         vid=g.vp._graphml_vertex_id
                         vidsrc=g.vp._graphml_vertex_id[e.target()]
                         rl= gt.find_vertex(g, vid, vidsrc+"Q" )
@@ -253,10 +259,10 @@ def __linkEdges(g, displayProgress=False):
                             g.ep.color[sEdge]='red'
                         else:
                              ed=utils.edge_description(g,e)
-                             logging.info("==>ERROR:LINK PRODUCT, no ref vertex found   %s "%(ed))
+                             logger.info("==>ERROR:LINK PRODUCT, no ref vertex found   %s "%(ed))
                                 
                  except:
-                        print("\nERROR IN ADDING EDGE(LINK PRODUCT) %s\n" %(traceback.format_exc() ) )
+                        logger.error("\nERROR IN ADDING EDGE(LINK PRODUCT) %s\n" %(traceback.format_exc() ) )
                         return -1
 
 
@@ -264,7 +270,7 @@ def __linkEdges(g, displayProgress=False):
             if (g.ep.spaim[e] in 'aim'):
 
                 try:
-                        logging.info("LINK ACTIVATOR, INHIBITOR, MODULATOR")
+                        logger.info("LINK ACTIVATOR, INHIBITOR, MODULATOR")
                         vid=g.vp._graphml_vertex_id
                         vidsrc=g.vp._graphml_vertex_id[e.source()]
                         rl= gt.find_vertex(g, vid, vidsrc+"Q" )
@@ -287,10 +293,10 @@ def __linkEdges(g, displayProgress=False):
 
                         else:
                              ed=utils.edge_description(g,e)
-                             logging.info("==>ERROR:LINK ACTIVATOR, INHIBITOR, MODULATOR, no ref vertex found   %s "%(ed))
+                             logger.error("==>ERROR:LINK ACTIVATOR, INHIBITOR, MODULATOR, no ref vertex found   %s "%(ed))
                                 
                 except:
-                        print("\nERROR IN ADDING EDGE(LINK ACTIVATOR, INHIBITOR, MODULATOR) %s\n" %(traceback.format_exc() ) )
+                        logger.error("\nERROR IN ADDING EDGE(LINK ACTIVATOR, INHIBITOR, MODULATOR) %s\n" %(traceback.format_exc() ) )
                         return -1
 
 ####
@@ -302,7 +308,7 @@ def __linkEdges(g, displayProgress=False):
                 g.ep.effect[e]='1'
                 if (catalysisBool):#ie if the reaction is moderated
                     try:
-                        logging.info("LINK SUBSTRATE")
+                        logger.info("LINK SUBSTRATE")
                         vid=g.vp._graphml_vertex_id
                         vidsrc=g.vp._graphml_vertex_id[e.source()]
                         rl= gt.find_vertex(g, vid, vidsrc+"Q" )
@@ -316,10 +322,10 @@ def __linkEdges(g, displayProgress=False):
                             g.ep.color[sEdge]='blue'
                         else:
                              ed=utils.edge_description(g,e)
-                             logging.info("==>ERROR:LINK SUBSTRATE, no ref vertex found   %s "%(ed))
+                             logger.info("==>ERROR:LINK SUBSTRATE, no ref vertex found   %s "%(ed))
                                 
                     except:
-                        print("\nERROR IN ADDING EDGE(LINK SUBSTRATE) %s\n" %(traceback.format_exc() ) )
+                        logger.error("\nERROR IN ADDING EDGE(LINK SUBSTRATE) %s\n" %(traceback.format_exc() ) )
                         return -1
 
 
@@ -332,7 +338,7 @@ def __linkEdges(g, displayProgress=False):
             substrateTamp.pop(sub)
             for v in substrateTamp:
                 try:
-                    logging.info("LINK SUBSTRATE (MODERATED REACTION)")
+                    logger.info("LINK SUBSTRATE (MODERATED REACTION)")
                     vid=g.vp._graphml_vertex_id
                     vidsrc=g.vp._graphml_vertex_id[v]  
                     rl= gt.find_vertex(g, vid, vidsrc+"Q" )
@@ -353,11 +359,11 @@ def __linkEdges(g, displayProgress=False):
                              else:
                                 msg="ERROR:LINK SUBSTRATE(MODERATED REACTION), no ref vertex found"
 
-                             logging.info("==>%s  %s "%(msg,ed))
+                             logger.info("==>%s  %s "%(msg,ed))
 
  
                 except:
-                    print("\nERROR IN ADDING EDGE(LINK SUBSTRATE (MODERATED REACTION) %s\n" %(traceback.format_exc() ) )
+                    logger.error("\nERROR IN ADDING EDGE(LINK SUBSTRATE (MODERATED REACTION) %s\n" %(traceback.format_exc() ) )
                     return -1
 
     g=gt.Graph(g, prune=True)
@@ -398,7 +404,7 @@ def prepare_spaim(input_graph,output_graph,output_image,checkInvertP=True):
     anormalConnections=__checkConnections(g)
     anormalNodes=np.reshape(anormalConnections, -1)
     #ADHOC INCLUSION
-    logging.info("\nAdhoc Inclusion Attempt...")
+    logger.info("\nAdhoc Inclusion Attempt...")
     for v in anormalNodes:
         undefAnormalButReaction=['TRANSCRIPTION', 'INHIBITION', 'PHYSICAL_STIMULATION', 'CATALYSIS', 'MODULATION', 'STATE_TRANSITION']
         g.vp.biopaxType[v]='UNDEF_CHEMICAL_ENTITY'
@@ -409,26 +415,26 @@ def prepare_spaim(input_graph,output_graph,output_image,checkInvertP=True):
             nm=g.vp.name[v].upper()
             if (bpType in nm):
 
-                logging.info("-fix abnormal reaction   %s " %(nm))
+                logger.info("-fix abnormal reaction   %s " %(nm))
 
                 g.vp.biopaxType[v]=bpType
                 g.vp.entityType[v]="reaction"
 
     if checkInvertP==True:
        #INVERT PRODUCT EDGES
-       logging.info("\ncheck if need to invert product edges...")
+       logger.info("\ncheck if need to invert product edges...")
        source=[]
        target=[]
        try:
          g.ep.color=g.new_edge_property("string")
        except: 
-         print("\nedge color already exists")
+         logger.error("\nedge color already exists")
 
          
        for e in g.edges():
         if (g.ep.spaim[e]=='p' and g.vp.entityType[e.source()]!="reaction"  and g.vp.entityType[e.target()]=="reaction" ):
             ed=utils.edge_description(g,e)
-            print("-inversion from %s -%s-> %s --[ %s ]--" %(e.source(),g.ep.spaim[e],e.target(), ed ))
+            logger.info("-inversion from %s -%s-> %s --[ %s ]--" %(e.source(),g.ep.spaim[e],e.target(), ed ))
             source.append(int(e.source()))
             target.append(int(e.target()))
        for s, t in zip(source, target):
@@ -530,8 +536,8 @@ def __undefNodesAndEdges(g):
         if (g.ep.spaim[e]=='undef'):
             undefTypeEdges.append((int(e.source()), int(e.target())))
 
-    print("\nnumber of undef entityType nodes: "+str(len(undefTypeNodes)))
-    print("number of undef spaim edges: "+str(len(undefTypeEdges)))
+    logger.info("\nnumber of undef entityType nodes: "+str(len(undefTypeNodes)))
+    logger.info("number of undef spaim edges: "+str(len(undefTypeEdges)))
     return (undefTypeNodes, undefTypeEdges)
 
 
@@ -544,13 +550,13 @@ def __checkConnections(g):
     try :
         g.vp.entityType[0]
     except:
-        print("\nERROR: ENTITY TYPE PROPERTY NOT FOUND\n")
+        logger.error("\nERROR: ENTITY TYPE PROPERTY NOT FOUND\n")
         return -1
     for e in g.edges():
         if (g.vp.entityType[e.source()]==g.vp.entityType[e.target()]):
             anormalConnections.append((int(e.source()), int(e.target())))
 
-    print("\nnumber of anormal connections: "+str(len(anormalConnections)))
+    logger.info("\nnumber of anormal connections: "+str(len(anormalConnections)))
     return anormalConnections
 
 
