@@ -6,6 +6,7 @@ __docformat__ = 'reStructuredText'
 
 
 import sys
+import logging
 import copy
 import pandas as pd
 import numpy as np 
@@ -20,6 +21,12 @@ from pybiomart.dataset import   Filter
 from pax2graphml import utils
 from pax2graphml import extract
 
+
+
+logger = logging.getLogger(__name__)
+logger.addHandler(logging.NullHandler())
+
+
 def property_values(g,annot_key):
     """ Alias of node_property_values"""
 
@@ -444,7 +451,7 @@ def annot_node_from_file(g,annot_file,map_key,new_prop,new_prop_type="string",de
     idx+=1
     if map_key=='index':
        key=idx
-       #key=g.vertex_index[node]
+
     else:
        key=g.vp[map_key][node]
 
